.. :changelog:

History
-------

0.2.0 (2016-12-23)
++++++++++++++++++

* [#5](https://github.com/founders4schools/django-surveys/issues/5) [FEATURE]
  Ability to customise the reviewer model
* [IMPROVEMENT] Namespaced the app settings a la DRF

0.1.1 (2016-12-23)
++++++++++++++++++

* [#6](https://github.com/founders4schools/django-surveys/issues/6) [BUG]
  Fix error message when rating is out of bounds


0.1.0 (2016-12-22)
++++++++++++++++++

* First release on PyPI.
